@@ -9,23 +9,19 @@ mod ffi;
 
 pub mod audio;
 pub mod event;
+pub mod texture;
+pub mod data;
+pub mod canvas;
 
 #[cfg(feature = "alloc")]
 pub extern crate alloc;
 
 #[derive(Default, Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
 pub struct Rectangle {
-    pub x: u16,
-    pub y: u16,
-    pub width: u16,
-    pub height: u16,
-}
-
-#[derive(Default, Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
-pub struct OpaqueColor {
-    pub r: u8,
-    pub g: u8,
-    pub b: u8,
+    pub x: i32,
+    pub y: i32,
+    pub width: i32,
+    pub height: i32,
 }
 
 #[derive(Default, Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
@@ -133,36 +129,3 @@ pub fn log(string: &str) {
         ffi::qwac_log(pointer, len);
     }
 }
-
-pub fn display(width_px: u16, height_px: u16) {
-    unsafe {
-        ffi::qwac_display(width_px, height_px);
-    }
-}
-
-pub fn clear_color(color: OpaqueColor) {
-    unsafe {
-        ffi::qwac_clear_color(color.r, color.g, color.b);
-    }
-}
-
-pub fn clear() {
-    unsafe {
-        ffi::qwac_clear();
-    }
-}
-
-pub fn fill_rectangle(rectangle: Rectangle, color: Color) {
-    unsafe {
-        ffi::qwac_fill_rectangle(
-            rectangle.x,
-            rectangle.y,
-            rectangle.width,
-            rectangle.height,
-            color.r,
-            color.g,
-            color.b,
-            color.a,
-        );
-    }
-}
